@@ -9,7 +9,7 @@ import tdcsm
 
 class coa():
 
-    version = "0.3.9.7.8"
+    version = "0.3.9.7.9"
     debug = False
 
     entryvars = {}
@@ -486,15 +486,15 @@ class coa():
                 self.coa.prepare_sql()
             elif name == 'execute_run':
                 self.systems_save2disk()
-                self.run_external('execute_run')
+                # self.run_external('execute_run')
+                self.coa.execute_run()
                 self.upload_get_lastrun_folder()
-                #self.coa.execute_run()
             elif name == 'make_customer_files':
                 self.coa.make_customer_files()
             elif name == 'upload_to_transcend':
                 self.systems_save2disk()
-                self.run_external('upload_to_transcend')
-                #self.coa.execute_run()
+                # self.run_external('upload_to_transcend')
+                self.coa.upload_to_transcend()
             elif name == 'motd':
                 self.coa.display_motd()
             elif name == 'last_output_folder':
@@ -559,7 +559,7 @@ class coa():
         self.set_defaults()
         app.wm_title(self.title)
         app.title(self.title)
-        app.geometry('720x770')
+        app.geometry('720x800')
 
         #-------------- Page Setup ------------------
         appframe = Frame(app, style="TFrame"); appframe.pack(fill=BOTH, expand=True)
